@@ -10,6 +10,9 @@ utils::globalVariables(".")
 #' x=tryCatch2(foo())
 #' x
 #' attributes(x)
+#' @importFrom glue glue_collapse
+#' @importFrom purrr map_chr
+#' @importFrom tibble tibble
 tryCatch2 = function(expr){
   errors = list()
   warnings = list()
@@ -87,6 +90,7 @@ formalArgs = function (def){
 
 
 #' Used for defaulting S3 methods to loaded function
+#' @importFrom cli cli_warn
 #' @importFrom utils getAnywhere
 #' @keywords internal
 #' @noRd
@@ -108,10 +112,11 @@ get_defined_function = function(name){
 
 
 
-#' @importFrom rlang as_function is_formula caller_env
-#' @importFrom purrr map map_dbl pmap_chr
-#' @importFrom glue glue glue_collapse
-#' @importFrom stringr str_subset
+#' @importFrom cli cli_abort cli_warn
+#' @importFrom glue glue_collapse
+#' @importFrom purrr map pmap_chr
+#' @importFrom rlang caller_env is_formula
+#' @importFrom stringr str_squish str_starts str_subset
 #' @keywords internal
 #' @noRd
 parse_funs = function(funs){
@@ -243,6 +248,8 @@ paste_classes = function(x){
 #' @param x a dataframe
 #' @keywords internal
 #' @noRd
+#' @importFrom glue glue
+#' @importFrom purrr map_chr
 paste_nameclasses = function(x){
   glue("{name} ({class})", name=names(x),
        class=map_chr(x, ~class(remove_label(.x))[1]))
@@ -251,8 +258,8 @@ paste_nameclasses = function(x){
 
 #' Test if @param method can be applied to @param x
 #' @param skip speed up the
-#' @importFrom utils methods
 #' @importFrom dplyr pull
+#' @importFrom utils methods
 #' @keywords internal
 #' @noRd
 has_method = function(x, method, skip=c("data.frame")){
@@ -270,63 +277,74 @@ has_method = function(x, method, skip=c("data.frame")){
 
 #' @keywords internal
 #' @noRd
+#' @importFrom purrr map
 percent_pattern_variables = function(){
-  x=c("cell", "row", "col")
-  n=c("n", "n_row", "n_col", "n_tot", "n_row_na", "n_col_na", "n_tot_na")
+  x=c("tot", "row", "col")
+  n=c("n", "n_row", "n_col", "n_tot")
+  n_na=c("n", "n_row_na", "n_col_na", "n_tot_na")
   p=paste0("p_", x)
   p_na=paste0(p, "_na")
   p_ci=map(p, ~paste0(.x, c("_inf", "_sup")))
   p_na_ci=map(p_na, ~paste0(.x, c("_inf", "_sup")))
-  c(n, p, p_na, p_ci, p_na_ci) %>% unlist()
+  # c(n, n_na, p, p_na, p_ci, p_na_ci) %>% unlist()
+  list(std=c(n, p, p_ci) %>% unlist(),
+       na=c(n_na, p_na, p_na_ci) %>% unlist())
 }
 
 
 #' @keywords internal
 #' @noRd
+#' @importFrom checkmate assert_subset
+#' @importFrom cli cli_abort
+#' @importFrom purrr safely walk
+#' @importFrom rlang set_names
+#' @importFrom stringr str_remove_all
 check_percent_pattern = function(percent_pattern){
-  # x=c("cell", "row", "col")
-  # n=c("n", "n_row", "n_col", "n_tot", "n_row_na", "n_col_na", "n_tot_na")
-  # p=paste0("p_", x)
-  # p_na=paste0(p, "_na")
-  # p_ci=map(p, ~paste0(.x, c("_inf", "_sup")))
-  # p_na_ci=map(p_na, ~paste0(.x, c("_inf", "_sup")))
-  # nm = list(n, p, p_na, p_ci, p_na_ci) %>% unlist()
+  assert_subset(names(percent_pattern), c("body", "total_row", "total_col", "total_all"))
+  walk(percent_pattern, ~{
+    nm = percent_pattern_variables() %>% unlist() %>% unique()
+    arg = rep(1, length(nm)) %>% set_names(nm) %>% as.list()
+    arg = c(.x, arg)
+    dummy = do.call(safely(glue), arg)
 
-  nm = percent_pattern_variables()
-  arg = rep(1, length(nm)) %>% set_names(nm) %>% as.list()
-  arg = c(percent_pattern, arg)
-  dummy = do.call(safely(glue), arg)
-
-  #TODO class(dummy$error) #https://github.com/tidyverse/glue/issues/229
-  if(!is.null(dummy$error)){
-    ok = c("n", "n_tot", "n_row", "n_col", "p_cell", "p_row", "p_col")
-    ok2 = c("p_xxx_inf", "p_xxx_sup")
-    percent_pattern = str_remove_all(percent_pattern, "\n")
-    cli_abort(c("Could not resolve a variable used in `percent_pattern`.",
-                i='Authorized variables are {.code {ok}}, along with {.code {ok2}} for proportions.',
-                i='Provided {.code percent_pattern}: {.code {percent_pattern}}',
-                x="Error: {.val {dummy$error$message}}"),
-              class="crosstable_percent_pattern_wrong_variable_error",
-              call=crosstable_caller$env)
-  }
+    # browser()
+    #TODO class(dummy$error) #https://github.com/tidyverse/glue/issues/229
+    if(!is.null(dummy$error)){
+      ok = c("n", "n_tot", "n_row", "n_col", "p_tot", "p_row", "p_col")
+      ok2 = c("p_xxx_inf", "p_xxx_sup")
+      .x = str_remove_all(.x, "\n")
+      cli_abort(c("Could not resolve a variable used in `percent_pattern`.",
+                  i='Authorized variables are {.code {ok}}, along with {.code {ok2}} for proportions.',
+                  i='Provided {.code percent_pattern}: {.code {.x}}',
+                  x="Error: {.val {dummy$error$message}}"),
+                class="crosstable_percent_pattern_wrong_variable_error",
+                call=crosstable_caller$env)
+    }
+  })
 }
 
 #' Rudimentary function to clean the names
 #'
 #' Avoids a dependency to janitor.
 #'
+#' @param string a string to clean
+#' @param from the current encoding. passed on to [iconv()]. `""` is the current locale.
+#'
 #' @keywords internal
 #' @noRd
+#' @encoding UTF-8
 #' @importFrom stringr str_remove_all
 #' @source janitor:::old_make_clean_names(), tweaked with iconv for accents
-crosstable_clean_names = function(string){
+#' @examples
+#' crosstable_clean_names("àccénts")
+crosstable_clean_names = function(string, from=""){
   old_names <- string
   new_names <- old_names %>%
     gsub("'", "", .) %>% gsub("\"", "", .) %>% gsub("%", "percent", .) %>%
     gsub("^[ ]+", "", .) %>% make.names(.) %>% gsub("[.]+", "_", .) %>%
-    gsub("[_]+", "_", .) %>% tolower(.) %>% gsub("_$", "", .)
-
-  new_names = new_names %>% str_remove_all("[\r\n]") %>% iconv(to="ASCII//TRANSLIT")
+    gsub("[_]+", "_", .) %>% tolower(.) %>% gsub("_$", "", .) %>%
+    iconv(from=from, to="ASCII//TRANSLIT") %>%
+    str_remove_all("[\r\n]")
 
   dupe_count <- vapply(seq_along(new_names), function(i) {
     sum(new_names[i] == new_names[1:i])
@@ -336,6 +354,21 @@ crosstable_clean_names = function(string){
 }
 
 
+#' not the same as attributes(x) = attributes(y)
+#' @keywords internal
+#' @noRd
+#' @importFrom cli cli_inform
+attributes_from = function(x, y, replace=FALSE, verbose=FALSE){
+  attr_x = names(attributes(x))
+  attr_y = names(attributes(y))
+  todo = if(isFALSE(replace)) setdiff(attr_y, attr_x) else attr_y
+  if(isTRUE(verbose)) cli_inform("Changing attributes: {.val {todo}}")
+  for(i in todo){
+    attr(x, i) = attr(y, i)
+  }
+  x
+}
+
 #' Computes the standard deviation of a date/datetime with the appropriate unit
 #'
 #' @param x a Date or Posix time
@@ -344,6 +377,7 @@ crosstable_clean_names = function(string){
 #' @keywords internal
 #' @noRd
 #' @importFrom checkmate assert
+#' @importFrom stats sd
 #'
 #' @examples
 #' x_date = as.Date(mtcars2$hp , origin="2010-01-01") %>% set_label("Date")
@@ -387,6 +421,7 @@ sd_date = function(x, date_unit=c("auto", "seconds", "minutes", "hours", "days",
 #' confint_numeric(iris$Sepal.Length)
 #' confint_numeric(mtcars2$hp_date)
 #' confint_numeric(mtcars2$hp_date, level=0.99)
+#' @importFrom stats qnorm sd
 confint_numeric = function(object, level=0.95, B=0){
   a = (1-level)/2
   ua = qnorm(1-a)
@@ -414,11 +449,15 @@ confint_numeric = function(object, level=0.95, B=0){
 #' @source binom:::binom.confint
 #' @source https://en.wikipedia.org/wiki/Binomial_proportion_confidence_interval
 #' @note validé avec PropCIs::scoreci
+#' @importFrom checkmate assert_integerish assert_numeric
+#' @importFrom stats qnorm
 #' @keywords internal
 #' @noRd
 confint_proportion = function(p, n,
                               method=c("wilson", "asymptotic"),
                               level=0.95){
+  assert_numeric(p, lower=0, upper=1)
+  assert_integerish(n)
   a = 1-level
   method = match.arg(method)
   z = qnorm(1-a/2)
@@ -448,7 +487,8 @@ confint_proportion = function(p, n,
 #'
 #' @keywords internal
 #' @noRd
-#' @importFrom stringr str_detect str_wrap str_replace_all
+#' @importFrom checkmate assert_count
+#' @importFrom stringr str_detect str_replace_all str_wrap
 #'
 #' @examples
 #' set.seed(0)
@@ -468,6 +508,9 @@ str_wrap2 = function(x, width, ...){
 #' @examples
 #' x=1:15;y="foobar"
 #' rec(x,y, sep=", ")
+#' @importFrom glue glue glue_collapse
+#' @importFrom purrr imap map
+#' @importFrom rlang set_names
 rec = function(..., sep=getOption("rec_sep", "\n"), sep_int=getOption("rec_sep", ", "),
                glue_pattern="{.name} = {.value}",
                max_length=getOption("rec_max_length", 10), .envir = parent.frame()){
@@ -495,6 +538,7 @@ rec = function(..., sep=getOption("rec_sep", "\n"), sep_int=getOption("rec_sep",
 #' @keywords internal
 #' @noRd
 #' @source https://github.com/tidyverse/forcats/issues/299
+#' @importFrom cli cli_warn
 fct = function(x=character(), levels, labels=levels, ...){
   miss_x = !x %in% levels
   if(any(miss_x)){
@@ -522,6 +566,29 @@ get_generic_labels = function(l=list()){
 }
 
 
+#' Rework when https://github.com/r-lib/cli/issues/229 is merged
+#' @keywords internal
+#' @importFrom cli ansi_strip
+#' @importFrom stringr str_replace
+#' @noRd
+ansi_align_by = function(text, pattern){
+  pos = gregexpr(pattern, ansi_strip(text)) |> unlist()
+  spaces = strrep("\u00a0", max(pos)-pos)
+  stringr::str_replace(text, pattern, paste0(spaces, pattern))
+}
+
+
+#' Needed from https://github.com/r-lib/cli/issues/505
+#' @keywords internal
+#' @noRd
+#' @importFrom rlang set_names
+#' @importFrom stringr str_remove_all
+cl = function(...){
+  nm = names(c(...)) %>% str_remove_all("\\d+")
+  c(...) %>% set_names(nm)
+}
+
+
 #' @source adapted from gtools::mixedorder() v3.9.2
 #' @keywords internal
 #' @noRd
@@ -600,6 +667,8 @@ mixedsort = function(x, decreasing=FALSE, na.last=TRUE, blank.last=FALSE,
 #' @keywords internal
 #' @noRd
 #' @source https://github.com/tidyverse/dplyr/issues/5563#issuecomment-721769342
+#' @importFrom dplyr across
+#' @importFrom tidyr unpack
 across_unpack = function(...) {
   out = across(...)
   tidyr::unpack(out, names(out), names_sep = "_")
@@ -613,6 +682,7 @@ as.data.frame.table = function(...) {
 
 #' @keywords internal
 #' @noRd
+#' @importFrom rlang is_formula
 is_one_sided = function(x) {
   is_formula(x) && length(x) == 2
 }
